@@ -1,4 +1,4 @@
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library("wrapr")
 
 variable <- as.name("angle")
@@ -7,7 +7,7 @@ sinterp(
   'variable name is .(variable)'
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 angle = 1:10
 variable <- as.name("angle")
 
@@ -18,24 +18,26 @@ evalb(
   
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 print(evalb)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
+if(requireNamespace("graphics", quietly = TRUE)) {
 bquote(
   
   plot(x = .(variable), 
        y = sin(.(variable)))
   
   )
+}
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 plotb <- bquote_function(graphics::plot)
 
 plotb(x = .(variable), 
       y = sin(.(variable)))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 f <- function() { 
   sin
 }
